summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/matrix/MatrixView.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/editors/matrix/MatrixView.h')
-rw-r--r--src/gui/editors/matrix/MatrixView.h22
1 files changed, 12 insertions, 10 deletions
diff --git a/src/gui/editors/matrix/MatrixView.h b/src/gui/editors/matrix/MatrixView.h
index 0951c8c..d65b86a 100644
--- a/src/gui/editors/matrix/MatrixView.h
+++ b/src/gui/editors/matrix/MatrixView.h
@@ -82,13 +82,14 @@ class LevelInfo;
class MatrixView : public EditView
{
Q_OBJECT
+ TQ_OBJECT
friend class MatrixSelector;
public:
MatrixView(RosegardenGUIDoc *doc,
std::vector<Segment *> segments,
- TQWidget *parent, bool drumMode);
+ TQWidget *tqparent, bool drumMode);
virtual ~MatrixView();
@@ -189,7 +190,7 @@ public:
* Adjust an X coord by world matrix
*/
double getXbyWorldMatrix(double value)
- { return m_canvasView->worldMatrix().m11() * value; }
+ { return m_canvasView->tqworldMatrix().m11() * value; }
double getXbyInverseWorldMatrix(double value)
{ return m_canvasView->inverseWorldMatrix().m11() * value; }
@@ -200,7 +201,7 @@ public:
* Repaint the control rulers
*
*/
- void repaintRulers();
+ void tqrepaintRulers();
/*
* Readjust the canvas size
@@ -291,7 +292,7 @@ public slots:
void slotToggleStepByStep();
/// status stuff
- void slotUpdateInsertModeStatus();
+ void slotUpdateInsertModetqStatus();
/// transforms
void slotTransformsQuantize();
@@ -519,7 +520,7 @@ protected:
/**
* save general Options like all bar positions and status as well
- * as the geometry and the recent file list to the configuration
+ * as the tqgeometry and the recent file list to the configuration
* file
*/
virtual void slotSaveOptions();
@@ -593,13 +594,13 @@ protected:
std::vector<MatrixStaff*> m_staffs;
- MatrixHLayout m_hlayout;
- MatrixVLayout m_vlayout;
+ MatrixHLayout m_htqlayout;
+ MatrixVLayout m_vtqlayout;
SnapGrid *m_snapGrid;
timeT m_lastEndMarkerTime;
- // Status bar elements
+ // tqStatus bar elements
TQLabel* m_hoveredOverAbsoluteTime;
TQLabel* m_hoveredOverNoteName;
TQLabel *m_selectionCounter;
@@ -668,12 +669,13 @@ protected:
};
// Commented this out - was a MatrixView inner class, but we get a warning
// that Q_OBJECT can't be used in an inner class - gl
//
-// class NoteSender : public QObject
+// class NoteSender : public TQObject
// {
// Q_OBJECT
+// TQ_OBJECT
// public:
// NoteSender(int i, int p) : m_insid(i), m_pitch(p) { }
@@ -668,12 +669,13 @@ protected:
};
// Commented this out - was a MatrixView inner class, but we get a warning
-// that Q_OBJECT can't be used in an inner class - gl
+// that TQ_OBJECT can't be used in an inner class - gl
//